@@ -1,5 +1,4 @@
 from .utils import (
-    is_accelerate_available,
     is_flax_available,
     is_inflect_available,
     is_onnx_available,
@@ -10,20 +9,13 @@ from .utils import (
 )
 
 
-__version__ = "0.7.0"
+__version__ = "0.7.2"
 
 from .configuration_utils import ConfigMixin
 from .onnx_utils import OnnxRuntimeModel
 from .utils import logging
 
 
-# This will create an extra dummy file "dummy_torch_and_accelerate_objects.py"
-# TODO: (patil-suraj, anton-l) maybe import everything under is_torch_and_accelerate_available
-if is_torch_available() and not is_accelerate_available():
-    error_msg = "Please install the `accelerate` library to use Diffusers with PyTorch. You can do so by running `pip install diffusers[torch]`. Or if torch is already installed, you can run `pip install accelerate`."  # noqa: E501
-    raise ImportError(error_msg)
-
-
 if is_torch_available():
     from .modeling_utils import ModelMixin
     from .models import AutoencoderKL, Transformer2DModel, UNet1DModel, UNet2DConditionModel, UNet2DModel, VQModel
